@@ -9,6 +9,7 @@ compas_fd
 .. toctree::
     :maxdepth: 1
 
+    compas_fd.constraints
     compas_fd.datastructures
     compas_fd.fd
     compas_fd.loads
@@ -25,7 +26,7 @@ __author__ = ['tom van mele <van.mele@arch.ethz.ch>']
 __copyright__ = 'Block Research Group - ETH Zurich'
 __license__ = 'MIT License'
 __email__ = 'van.mele@arch.ethz.ch'
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 
 get = compas.get
@@ -40,3 +41,7 @@ TEMP = os.path.abspath(os.path.join(HOME, 'temp'))
 
 
 __all__ = ['HOME', 'DATA', 'DOCS', 'TEMP', 'get']
+
+__all_plugins__ = [
+    'compas_fd.install'
+]
